# flake8: noqa
from .bimodal import Bimodal
from .bimodal_noised import BimodalNoised
from .discrete import Discrete
from .hiff import Hiff
from .hiff_star import HiffStar
from .isg.isg import IsingSpinGlass
from .step_bimodal import StepBimodal
from .step_trap import StepTrap
from .trap import Trap
